@@ -745,8 +745,11 @@ type Runner struct {
 	// Labels is list label names to select a runner to run a job. There are preset labels and user
 	// defined labels. Runner matching to the labels is selected.
 	Labels []*String
-	// Expression is a string when expression syntax ${{ }} is used for this section. Related issue is #164.
-	Expression *String
+	// LabelsExpr is a string when expression syntax ${{ }} is used for this section. Related issue is #164.
+	LabelsExpr *String
+	// Group is a group of runners specified in runs-on: section. It is nil when no group is specified.
+	// https://docs.github.com/en/actions/using-workflows/workflow-syntax-for-github-actions#choosing-runners-in-a-group
+	Group *String
 }
 
 // WorkflowCallInput is a normal input for workflow call.
