@@ -16,6 +16,11 @@ type Config struct {
 		// Labels is label names for self-hosted runner.
 		Labels []string `yaml:"labels"`
 	} `yaml:"self-hosted-runner"`
+	// ConfigVariables is names of configuration variables used in the checked workflows. When this value is nil,
+	// property names of `vars` context will not be checked. Otherwise actionlint will report a name which is not
+	// listed here as undefined config variables.
+	// https://docs.github.com/en/actions/learn-github-actions/variables
+	ConfigVariables []string `yaml:"config-variables"`
 }
 
 func parseConfig(b []byte, path string) (*Config, error) {
@@ -27,7 +32,8 @@ func parseConfig(b []byte, path string) (*Config, error) {
 	return &c, nil
 }
 
-func readConfigFile(path string) (*Config, error) {
+// ReadConfigFile reads actionlint config file (actionlint.yaml) from the given file path.
+func ReadConfigFile(path string) (*Config, error) {
 	b, err := os.ReadFile(path)
 	if err != nil {
 		return nil, fmt.Errorf("could not read config file %q: %w", path, err)
@@ -37,8 +43,12 @@ func readConfigFile(path string) (*Config, error) {
 
 func writeDefaultConfigFile(path string) error {
 	b := []byte(`self-hosted-runner:
-  # Labels of self-hosted runner in array of string
+  # Labels of self-hosted runner in array of strings.
   labels: []
+# Configuration variables in array of strings defined in your repository or
+# organization. ` + "`null`" + ` means disabling configuration variables check.
+# Empty array means no configuration variable is allowed.
+config-variables: null
 `)
 	if err := os.WriteFile(path, b, 0644); err != nil {
 		return fmt.Errorf("could not write default configuration file at %q: %w", path, err)
