@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -133,7 +134,7 @@ func NewLinter(out io.Writer, opts *LinterOptions) (*Linter, error) {
 
 	var cfg *Config
 	if opts.ConfigFile != "" {
-		c, err := readConfigFile(opts.ConfigFile)
+		c, err := ReadConfigFile(opts.ConfigFile)
 		if err != nil {
 			return nil, err
 		}
@@ -413,12 +414,16 @@ func (l *Linter) LintFile(path string, project *Project) ([]*Error, error) {
 	return errs, err
 }
 
-// Lint lints YAML workflow file content given as byte sequence. The path parameter is used as file
-// path the content came from. Setting "<stdin>" to path parameter indicates the output came from
-// STDIN.
-// Note that only given Project instance is used for configuration. No config is automatically loaded
-// based on path parameter.
+// Lint lints YAML workflow file content given as byte slice. The path parameter is used as file
+// path where the content came from. Setting "<stdin>" to path parameter indicates the output came
+// from STDIN.
+// When nil is passed to the project parameter, it tries to find the project from the path parameter.
 func (l *Linter) Lint(path string, content []byte, project *Project) ([]*Error, error) {
+	if project == nil && path != "<stdin>" {
+		if _, err := os.Stat(path); !errors.Is(err, fs.ErrNotExist) {
+			project = l.projects.At(path)
+		}
+	}
 	proc := newConcurrentProcess(runtime.NumCPU())
 	dbg := l.debugWriter()
 	localActions := NewLocalActionsCache(project, dbg)
@@ -461,7 +466,7 @@ func (l *Linter) check(
 	if l.defaultConfig != nil {
 		cfg = l.defaultConfig
 	} else if project != nil {
-		c, err := project.Config()
+		c, err := project.LoadConfig()
 		if err != nil {
 			return nil, err
 		}
@@ -483,16 +488,11 @@ func (l *Linter) check(
 	if w != nil {
 		dbg := l.debugWriter()
 
-		var labels []string
-		if cfg != nil {
-			labels = cfg.SelfHostedRunner.Labels
-		}
-
 		rules := []Rule{
 			NewRuleMatrix(),
 			NewRuleCredentials(),
 			NewRuleShellName(),
-			NewRuleRunnerLabel(labels),
+			NewRuleRunnerLabel(),
 			NewRuleEvents(),
 			NewRuleJobNeeds(),
 			NewRuleAction(localActions),
@@ -535,6 +535,11 @@ func (l *Linter) check(
 				r.EnableDebug(dbg)
 			}
 		}
+		if cfg != nil {
+			for _, r := range rules {
+				r.SetConfig(cfg)
+			}
+		}
 
 		if err := v.Visit(w); err != nil {
 			l.debug("error occurred while visiting workflow syntax tree: %v", err)
@@ -562,12 +567,12 @@ func (l *Linter) check(
 		all = filtered
 	}
 
-	sort.Sort(ByErrorPosition(all))
-
 	for _, err := range all {
 		err.Filepath = path // Populate filename in the error
 	}
 
+	sort.Stable(ByErrorPosition(all))
+
 	if l.logLevel >= LogLevelVerbose {
 		elapsed := time.Since(start)
 		l.log("Found total", len(all), "errors in", elapsed.Milliseconds(), "ms for", path)
